Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(94)

Unified Diff: src/platform/vboot_reference/vboot_firmware/include/load_kernel_fw.h

Issue 2561001: Fix LoadKernel() (Closed) Base URL: ssh://gitrw.chromium.org/chromiumos
Patch Set: Make requested changes. Rename bootloader start to bootloader address. Created 10 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/platform/vboot_reference/vboot_firmware/include/load_kernel_fw.h
diff --git a/src/platform/vboot_reference/vboot_firmware/include/load_kernel_fw.h b/src/platform/vboot_reference/vboot_firmware/include/load_kernel_fw.h
index f34d53112ec7a4c16f44909f7d973cdfab5966fa..f4c512a60d910b700b151af003f6b0b9bbb583a2 100644
--- a/src/platform/vboot_reference/vboot_firmware/include/load_kernel_fw.h
+++ b/src/platform/vboot_reference/vboot_firmware/include/load_kernel_fw.h
@@ -38,7 +38,7 @@ typedef struct LoadKernelParams {
* LOAD_KERNEL_SUCCESS */
uint64_t partition_number; /* Partition number to boot on current device
* (1...M) */
- void *bootloader_start; /* Start of bootloader image */
+ uint64_t bootloader_address; /* Address of bootloader image in RAM */
uint64_t bootloader_size; /* Size of bootloader image in bytes */
} LoadKernelParams;

Powered by Google App Engine
This is Rietveld 408576698